"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const nd_gpio_rf_1 = require("nd-gpio-rf");
class GpioRFCollect {
    constructor(RED, node, config) {
        this.RED = RED;
        this.config = config;
        this.node = node;
        this.init();
    }
    init() {
        this.node.status({});
        if (this.config.pin) {
            this.gpio = new nd_gpio_rf_1.GpioRF();
            this.node.status({ fill: "green", shape: "dot", text: "connected" });
        }
        this.node.on('input', (msg) => {
            if (this.gpio)
                this.recvRFCode(msg);
            else
                this.node.status({ fill: "red", shape: "dot", text: "no connected pin" });
        });
        this.node.on('close', () => {
        });
    }
    recvRFCode(msg) {
        console.log("Start collect......");
        this.node.status({ fill: "yellow", shape: "dot", text: "Collecting" });
        let params = {
            pin: parseInt(this.config.pin),
            maxCount: parseInt(this.config.maxCount),
            milliTimeout: parseInt(this.config.milliTimeout)
        };
        this.gpio.collect(params, (error, micros) => {
            if (!error) {
                msg.payload = micros;
                this.node.status({ fill: "green", shape: "dot", text: "Collect OK" });
                this.node.send(msg);
            }
            else {
                this.node.error(error);
                this.node.status({ fill: "red", shape: "dot", text: error });
            }
        });
        return true;
    }
}
module.exports = (RED) => {
    function CreateNode(config) {
        RED.nodes.createNode(this, config);
        new GpioRFCollect(RED, this, config);
    }
    RED.nodes.registerType("gpio-rf-collect", CreateNode);
};
