"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const nd_gpio_rf_1 = require("nd-gpio-rf");
class GpioRFSender {
    constructor(RED, node, config) {
        this.RED = RED;
        this.config = config;
        this.node = node;
        this.init();
    }
    init() {
        this.node.status({});
        if (this.config.pin) {
            this.gpio = new nd_gpio_rf_1.GpioRF();
            this.node.status({ fill: "green", shape: "dot", text: "connected" });
        }
        this.node.on('input', (msg) => {
            if (this.gpio) {
                msg.payload = msg.payload || this.config.strMicros;
                if (msg.payload) {
                    this.sendRFCode(msg);
                }
                else {
                    this.node.status({ fill: "red", shape: "dot", text: "no codes" });
                }
            }
            else {
                this.node.status({ fill: "red", shape: "dot", text: "no connected pin" });
            }
        });
        this.node.on('close', () => {
        });
    }
    sendRFCode(msg) {
        return __awaiter(this, void 0, void 0, function* () {
            this.node.status({ fill: "yellow", shape: "dot", text: "Start Send......" });
            let params = {
                pin: parseInt(msg.pin || this.config.pin),
                strMicros: msg.payload,
                count: parseInt(msg.count || this.config.count),
            };
            this.gpio.send(params, (error) => {
                if (!error) {
                    this.node.status({ fill: "green", shape: "dot", text: "Send OK" });
                    this.node.send(msg);
                }
                else {
                    this.node.error(error);
                    this.node.status({ fill: "red", shape: "dot", text: error });
                }
            });
            return true;
        });
    }
}
module.exports = (RED) => {
    function CreateNode(config) {
        RED.nodes.createNode(this, config);
        new GpioRFSender(RED, this, config);
    }
    RED.nodes.registerType("gpio-rf-sender", CreateNode);
};
